SystemOrganization addCategory: #'Essential-SUnit'!
SystemOrganization addCategory: #'Essential-SLint'!

SmalllintContext subclass: #ESLintContext
	instanceVariableNames: 'sourceCode parseTrees ignored'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESLintContext methodsFor: 'private' stamp: 'lr 10/28/2005 13:27'!
buildParseTree
	"Parsing in Squeak is slow, therefor it is a good idea to cache it. This gives a average speedup of 30%."

	"<lint: #expect rule: #overridesSuper rational: 'to use the cached source-code we cannot directly use the super method'>"

	^ (parseTrees at: class ifAbsentPut: [ IdentityDictionary new ])
		at: selector ifAbsentPut: [ self buildParseTreeActually ].! !

!ESLintContext methodsFor: 'private' stamp: 'lr 10/28/2005 12:51'!
buildParseTreeActually
	| tree |
	tree := RBParser 
		parseMethod: self sourceCode 
		onError: [ :string :pos | ^ RBParser parseMethod: 'method' ].
	^ tree.! !

!ESLintContext methodsFor: 'testing' stamp: 'lr 10/31/2005 17:48'!
hasSourceCode
	(sourceCode at: class ifAbsent: [ ^ false ])
		at: selector ifAbsent: [ ^ false ].
	^ true.! !

!ESLintContext methodsFor: 'initialize' stamp: 'lr 10/28/2005 12:53'!
initialize
	super initialize.
	sourceCode := IdentityDictionary new.
	parseTrees := IdentityDictionary new.
	ignored := IdentityDictionary new.! !

!ESLintContext methodsFor: 'testing' stamp: 'lr 10/28/2005 01:23'!
isIgnored: aSelector
	^ ((ignored at: class ifAbsent: [ ^ false ])
		at: selector ifAbsent: [ ^ false ])
			includes: aSelector.! !

!ESLintContext methodsFor: 'pragmas' stamp: 'lr 10/31/2005 17:48'!
lint: aWhatSelector rule: aRuleSelector
	"<lint: #ignore rule: #collectionMessagesToExternalObject rational: 'lint is wrong here'>"
	(((aWhatSelector = #ignore
		ifTrue: [ ignored ]
		ifFalse: [
			aWhatSelector = #expect
				ifTrue: [ ignored ]
				ifFalse: [ ^ self warn: 'invalid selector' ] ])
		at: class ifAbsentPut: [ IdentityDictionary new ])
			at: selector ifAbsentPut: [ IdentitySet new ])
				add: aRuleSelector.! !

!ESLintContext methodsFor: 'pragmas' stamp: 'lr 10/27/2005 22:18'!
lint: aWhatSelector rule: aRuleSelector rational: aString
	self lint: aWhatSelector rule: aRuleSelector.! !

!ESLintContext methodsFor: 'private' stamp: 'lr 10/28/2005 13:45'!
parsePragma
	| stream |
	stream := self sourceCode readStream.
	[ stream atEnd ] whileFalse: [
		stream upToAll: '<' , 'lint:'.
		stream atEnd ifFalse: [
			[ self class compilerClass new
				evaluate: 'self lint:' , (stream upTo: $>) 
				in: thisContext to: self notifying: nil
				ifFail: [ self warn: 'invalid pragma' ] 
				logged: false ]
					on: SyntaxErrorNotification 
					do: [ :err | self warn: 'syntax error in pragma' ] ].]! !

!ESLintContext methodsFor: 'accessing' stamp: 'lr 10/28/2005 12:53'!
selectedClass: anObject
	super selectedClass: anObject.
	self hasSourceCode
		ifFalse: [ self parsePragma ].! !

!ESLintContext methodsFor: 'accessing' stamp: 'lr 10/28/2005 12:57'!
selector: anObject
	super selector: anObject.
	self hasSourceCode
		ifFalse: [ self parsePragma ].! !

!ESLintContext methodsFor: 'accessing' stamp: 'lr 10/28/2005 12:55'!
sourceCode
	"Accessing source code in Squeak is slow, therefor it is a good idea to cache it. This gives a average speedup of 20%."

	^ (sourceCode at: class ifAbsentPut: [ IdentityDictionary new ])
		at: selector 
		ifAbsentPut: [
			selector isNil
				ifTrue: [ class comment ]
				ifFalse: [ super sourceCode ] ].! !

!ESLintContext methodsFor: 'private' stamp: 'lr 10/28/2005 01:13'!
warn: aString
	Transcript nextPutAll: self selectedClass name.
	self selector isNil 
		ifFalse: [ Transcript nextPutAll: '>>'; nextPutAll: self selector ].
	Transcript space; nextPutAll: aString; cr; endEntry.! !

TestResource subclass: #ESLintTestResource
	instanceVariableNames: 'context environments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESLintTestResource methodsFor: 'accessing' stamp: 'lr 10/26/2005 15:40'!
context
	^ context! !

!ESLintTestResource methodsFor: 'accessing' stamp: 'lr 10/28/2005 00:17'!
environmentFor: aTestCase
	^ environments at: aTestCase class ifAbsentPut: [ aTestCase environment ].! !

!ESLintTestResource methodsFor: 'running' stamp: 'lr 10/28/2005 12:38'!
setUp
	super setUp.
	context := ESLintContext new.
	environments := IdentityDictionary new.! !

!ESLintTestResource methodsFor: 'running' stamp: 'lr 10/26/2005 16:18'!
tearDown
	super tearDown.
	context := environments := nil.! !

Object subclass: #ESCoverage
	instanceVariableNames: 'coverage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SUnit'!

!ESCoverage methodsFor: 'accessing' stamp: 'lr 10/24/2005 22:45'!
environment
	| environment |
	environment := SelectorEnvironment onEnvironment: BrowserEnvironment new.
	coverage keysAndValuesDo: [ :key :value |
		key isBehavior ifTrue: [
			value do: [ :each |
				environment addClass: key selector: each ] ] ].
	^ environment.! !

!ESCoverage methodsFor: 'initialization' stamp: 'lr 10/24/2005 21:17'!
initialize
	super initialize.
	coverage := IdentityDictionary new.! !

!ESCoverage methodsFor: 'execution' stamp: 'lr 11/3/2005 10:29'!
run: aBlock
	"<lint: #ignore rule: #collectionMessagesToExternalObject rational: 'lint is wrong here'>"

	| previous |
	previous := aBlock .
	thisContext sender
		runSimulated: aBlock
		contextAtEachStep: [ :current |
			current == previous ifFalse: [
				previous sender isNil ifFalse: [
					(coverage 
						at: (current receiver class 
							whichClassIncludesSelector: current selector)
						ifAbsentPut: [ IdentitySet new ])
							add: current selector ]. 
				previous := current ] ].! !

Object subclass: #ESTestRunner
	instanceVariableNames: 'categories categoriesSelected classes classesSelected failedList failedSelected errorList errorSelected lastUpdate result'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SUnit'!

!ESTestRunner commentStamp: 'lr 10/28/2005 13:50' prior: 0!
<lint: #ignore rule: #classNotReferenced rational: 'this view is only accessed from menus'>
<lint: #ignore rule: #badMessage rational: 'this is a common morphic pattern'>
!

!ESTestRunner class methodsFor: 'initialization' stamp: 'lr 10/27/2005 00:09'!
initialize
	TheWorldMenu registerOpenCommand: (Array 
		with: 'Essential Test Runner' 
		with: (Array
			with: self
			with: #open)).! !

!ESTestRunner class methodsFor: 'instance-creation' stamp: 'lr 10/8/2005 18:35'!
open
	^ ToolBuilder open: self new.! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/31/2005 15:31'!
baseClass
	^ TestCase! !

!ESTestRunner methodsFor: 'processing' stamp: 'lr 10/31/2005 17:43'!
basicRunSuite: aTestSuite do: aBlock
	self basicSetUpSuite: aTestSuite.
	[ aTestSuite name isEmptyOrNil
		ifTrue: [ aTestSuite tests do: aBlock ]
		ifFalse: [ aTestSuite tests do: aBlock displayingProgress: aTestSuite name ] ]
			ensure: [ self basicTearDownSuite: aTestSuite ].
	! !

!ESTestRunner methodsFor: 'processing' stamp: 'lr 10/27/2005 10:04'!
basicSetUpSuite: aTestSuite
	aTestSuite resources do: [ :each |
		each isAvailable
			ifFalse: [ each signalInitializationError ] ].! !

!ESTestRunner methodsFor: 'processing' stamp: 'lr 10/27/2005 10:04'!
basicTearDownSuite: aTestSuite
	aTestSuite resources do: [ :each | each reset ].! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/10/2005 21:34'!
browseReferencedClasses
	| references |
	references := classesSelected gather: [ :class |
		class methodDict values , class class methodDict values gather: [ :method |
			method literals
				select: [ :each | each isVariableBinding and: [ each value isBehavior ] ]
				thenCollect: [ :each | each value ] ] ].
	(BrowserEnvironment new forClasses: references asSet)
		label: 'Referenced Classes';
		openEditor.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/10/2005 21:26'!
browseSentMessages
	| references |
	references := classesSelected gather: [ :class |
		class methodDict values , class class methodDict values gather: [ :method |
			(method literals copyWithoutAll: class allSelectors , class class allSelectors)
				select: [ :each | each isSymbol ] ] ].
	self systemNavigation
		browseAllImplementorsOfList: references asSet
		title: 'Sent Messages'.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/24/2005 19:26'!
browseTestClasses
	(BrowserEnvironment new forClasses: classesSelected asSet)
		label: 'Test Classes';
		openEditor.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/28/2005 15:29'!
buildButtonsWith: aBuilder
	^ aBuilder pluggablePanelSpec new
		model: self;
		layout: #horizontal;
		children: (self buttons collect: [ :each |
			aBuilder pluggableActionButtonSpec new
				model: self; action: each key; 
				color: #defaultButtonColor;
				label: each value;
				yourself ]);
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/31/2005 15:12'!
buildCategoriesWith: aBuilder
	^ aBuilder pluggableMultiSelectionListSpec new
		model: self;
		list: #categoryList;
		menu: #categoryMenu:;
		getIndex: #categorySelected;
		setIndex: #categorySelected:;
		getSelectionList: #categoryAt:;
		setSelectionList: #categoryAt:put:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/17/2005 09:13'!
buildClassesWith: aBuilder
	^ aBuilder pluggableMultiSelectionListSpec new
		model: self;
		list: #classList;
		menu: #classMenu:;
		getIndex: #classSelected;
		setIndex: #classSelected:;
		getSelectionList: #classAt:;
		setSelectionList: #classAt:put:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/6/2005 19:39'!
buildErrorListWith: aBuilder
	^ aBuilder pluggableListSpec new
		model: self;
		name: 'Error List';
		list: #errorList; 
		getIndex: #errorSelected; 
		setIndex: #errorSelected:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/6/2005 19:47'!
buildFailureListWith: aBuilder
	^ aBuilder pluggableListSpec new
		model: self;
		name: 'Failure List';
		list: #failedList; 
		getIndex: #failedSelected; 
		setIndex: #failedSelected:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/8/2005 23:06'!
buildStatusWith: aBuilder
	^ aBuilder pluggableInputFieldSpec new
		model: self;
		color: #statusColor;
		getText: #statusText;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/31/2005 15:12'!
buildWith: aBuilder
	| window |
	window := aBuilder pluggableWindowSpec new
		model: self; label: self label; extent: self extent;
		children: (OrderedCollection new 
			add: ((self buildCategoriesWith: aBuilder)
				frame: (0.00 @ 0.00 corner: 0.25 @ 0.92 );
				yourself);
			add: ((self buildClassesWith: aBuilder)
				frame: (0.25 @ 0.00 corner: 0.50 @ 0.92 );
				yourself);
			add: ((self buildStatusWith: aBuilder)
				frame: (0.50 @ 0.00 corner: 1.00 @ 0.08);
				yourself);
			add: ((self buildFailureListWith: aBuilder)
				frame: (0.50 @ 0.08 corner: 1.00 @ 0.50);
				yourself);
			add: ((self buildErrorListWith: aBuilder)
				frame: (0.50 @ 0.50 corner: 1.00 @ 0.92);
				yourself);
			add: ((self buildButtonsWith: aBuilder)
				frame: (0.00 @ 0.92 corner: 1.00 @ 1.00);
				yourself);
			yourself);
		yourself.
	^ aBuilder build: window.! !

!ESTestRunner methodsFor: 'accessing-ui' stamp: 'lr 10/28/2005 15:30'!
buttons
	^ Array
		with: #runAll -> 'Run All'
		with: #runProfiled -> 'Run Profiled'
		with: #runCoverage -> 'Run Coverage'
		with: #runFailures -> 'Run Failures'
		with: #runErrors -> 'Run Errors'.! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 10/31/2005 15:09'!
categoryAt: anIndex
	^ categoriesSelected includes: (categories at: anIndex ifAbsent: [ ^ false ]).! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 10/31/2005 15:51'!
categoryAt: anInteger put: aBoolean
	categoriesSelected := categoriesSelected
		perform: (aBoolean ifTrue: [ #copyWith: ] ifFalse: [ #copyWithout: ])
		with: (categories at: anInteger ifAbsent: [ ^ self ]).
	self changed: #categorySelected; updateClasses.! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 10/31/2005 15:10'!
categoryList
	^ categories! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 11/1/2005 19:25'!
categoryMenu: aMenu
	^ aMenu
		title: 'Categories';
		add: 'Select all' action: #selectAllCategories;
		add: 'Select inversion' action: #selectInverseCategories;
		add: 'Select none' action: #selectNoCategories;
		addLine;
		add: 'Filter...' action: #filterCategories;
		addLine;
		add: 'Refresh' action: #updateCategories;
		yourself.! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 10/31/2005 15:11'!
categorySelected
	^ 0! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 10/31/2005 15:12'!
categorySelected: anInteger
	self changed: #categorySelected.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 19:58'!
classAt: anInteger
	^ classesSelected includes: (classes at: anInteger ifAbsent: [ ^ false ]).! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 22:32'!
classAt: anInteger put: aBoolean
	classesSelected := classesSelected
		perform: (aBoolean ifTrue: [ #copyWith: ] ifFalse: [ #copyWithout: ])
		with: (classes at: anInteger ifAbsent: [ ^ self ]).
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/10/2005 11:24'!
classList
	| offset ident |
	classes isEmpty ifTrue: [ ^ classes ].
	offset := classes first allSuperclasses size.
	^ classes collect: [ :each |
		ident := String 
			new: 2 * (0 max: each allSuperclasses size - offset) 
			withAll: $ .
		each isAbstract
			ifFalse: [ ident , each name ]
			ifTrue: [ 
				ident asText , each name asText 
					addAttribute: TextEmphasis italic;
					yourself ] ].! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/10/2005 22:09'!
classMenu: aMenu
	^ aMenu
		title: 'Classes';
		add: 'Browse classes' action: #browseTestClasses;
		add: 'Browse referenced classes' action: #browseReferencedClasses;
		add: 'Browse sent messages' action: #browseSentMessages;
		addLine;
		add: 'Select all' action: #selectAllClasses;
		add: 'Select subclasses' action: #selectSubclasses;
		add: 'Select inversion' action: #selectInverseClasses;
		add: 'Select none' action: #selectNoClasses;
		addLine;
		add: 'Filter...' action: #filterClasses;
		addLine;
		add: 'Refresh' action: #updateClasses;
		yourself.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 22:30'!
classSelected
	^ 0! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 22:30'!
classSelected: anInteger
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/31/2005 17:01'!
debugSuite: aTestSuite
	self basicRunSuite: aTestSuite do: [ :each | each debug ].! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/31/2005 17:42'!
debug: aTestCase
	self debugSuite: (TestSuite new
		addTest: aTestCase; 
		yourself).! !

!ESTestRunner methodsFor: 'private' stamp: 'lr 10/28/2005 13:28'!
defaultBackgroundColor
	"<lint: #expect rule: #overridesSuper rational: 'we want a different color than the parent'>"

	^ Color orange.! !

!ESTestRunner methodsFor: 'private' stamp: 'lr 10/10/2005 11:39'!
defaultButtonColor
	^ self defaultBackgroundColor muchLighter.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:37'!
errorList
	^ errorList collect: [ :each | each printString ].! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 19:46'!
errorSelected
	^ errorList indexOf: errorSelected.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/27/2005 10:37'!
errorSelected: anInteger
	errorSelected := errorList at: anInteger ifAbsent: nil.
	self changed: #errorSelected.
	errorSelected ifNotNil: [ self debug: errorSelected ].! !

!ESTestRunner methodsFor: 'accessing-ui' stamp: 'lr 10/8/2005 18:39'!
extent
	^ 640 @ 480! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:37'!
failedList
	^ failedList collect: [ :each | each printString ].! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 19:47'!
failedSelected
	^ failedList indexOf: failedSelected.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 20:14'!
failedSelected: anInteger
	failedSelected := failedList at: anInteger ifAbsent: nil.
	self changed: #failedSelected.
	failedSelected ifNotNil: [ self debug: failedSelected ].! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 11/1/2005 19:27'!
filterCategories
	| pattern |
	pattern := UIManager default 
		request: 'Pattern to select categories:' 
		initialAnswer: '*'.
	pattern isNil ifTrue: [ ^ self ].
	categoriesSelected := (categories 
		select: [ :each | pattern match: each ]) asSet.
	self changed: #categorySelected; updateClasses.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/1/2005 19:31'!
filterClasses
	| pattern |
	pattern := UIManager default 
		request: 'Pattern to select tests:' 
		initialAnswer: '*'.
	pattern isNil ifTrue: [ ^ self ].
	classesSelected := (classes select: [ :each | 
		pattern match: each name ]) asSet.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'utilities' stamp: 'lr 10/31/2005 15:41'!
findCategories
	| visible |
	visible := Set new.
	self baseClass withAllSubclassesDo: [ :each | 
		visible add: each category ].
	^ Array streamContents: [ :stream |
		Smalltalk organization categories do: [ :each |
			(visible includes: each)
				ifTrue: [ stream nextPut: each ] ] ].! !

!ESTestRunner methodsFor: 'utilities' stamp: 'lr 10/31/2005 16:05'!
findClassesForCategories: aCollection
	| items |
	aCollection isEmpty 
		ifTrue: [ ^ self baseClass withAllSubclasses ].
	items := aCollection gather: [ :category |
		((Smalltalk organization listAtCategoryNamed: category)
			collect: [ :each | Smalltalk at: each ])
			select: [ :each | each includesBehavior: self baseClass ] ].
	^ items asSet.! !

!ESTestRunner methodsFor: 'initialization' stamp: 'lr 10/31/2005 16:15'!
initialize
	super initialize.
	failedList := errorList := Array new.
	self updateCategories; updateClasses; reset.! !

!ESTestRunner methodsFor: 'accessing-ui' stamp: 'lr 10/27/2005 10:43'!
label
	^ 'Essential Test Runner' ! !

!ESTestRunner methodsFor: 'private' stamp: 'lr 10/27/2005 10:32'!
label: aString forSuite: aTestSuite
	^ String streamContents: [ :stream |
		stream nextPutAll: 'Running '; print: aTestSuite tests size; space; nextPutAll: aString.
		aTestSuite tests size > 1 ifTrue: [ stream nextPut: $s ] ]. ! !

!ESTestRunner methodsFor: 'private' stamp: 'lr 10/28/2005 13:50'!
perform: selector orSendTo: otherTarget
	^ (self respondsTo: selector)
		ifTrue: [ self perform: selector ]
		ifFalse: [ super perform: selector orSendTo: otherTarget ].! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/8/2005 22:52'!
reset
	self result: TestResult new; updateResults.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 15:47'!
result
	^ result! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:47'!
result: aResult
	result := aResult! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/20/2005 16:28'!
runAll
	self reset; runSuite: self suiteAll.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/31/2005 17:18'!
runCoverage
	| coverage |
	coverage := ESCoverage new.
	self reset.
	self 
		basicRunSuite: self suiteAll
		do: [ :each | coverage run: [ each run: result ] ].
	self updateResults.
	coverage environment
		label: 'Covered Methods';
		openEditor.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/8/2005 23:02'!
runErrors
	self result instVarNamed: 'errors' put: OrderedCollection new.
	self runSuite: self suiteErrors.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/27/2005 10:42'!
runFailures
	self result instVarNamed: 'failures' put: Set new.
	self runSuite: self suiteFailures.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/31/2005 17:13'!
runProfiled
	MessageTally spyOn: [ self runAll ].! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/31/2005 17:00'!
runSuite: aTestSuite
	self basicRunSuite: aTestSuite do: [ :each | self runTest: each ].
	self updateResults.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 11/3/2005 09:15'!
runTest: aTestCase
	aTestCase run: result.
	self updateStatus: true.! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 11/1/2005 19:27'!
selectAllCategories
	categoriesSelected := categories asSet.
	self changed: #categorySelected; updateClasses.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/1/2005 19:32'!
selectAllClasses
	classesSelected := classes asSet.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 11/1/2005 19:27'!
selectInverseCategories
	categoriesSelected := categories asSet 
		removeAll: categoriesSelected;
		yourself.
	self changed: #categorySelected; updateClasses.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/1/2005 19:32'!
selectInverseClasses
	classesSelected := classes asSet 
		removeAll: classesSelected;
		yourself.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-categories' stamp: 'lr 11/1/2005 19:27'!
selectNoCategories
	categoriesSelected := Set new.
	self changed: #categorySelected; updateClasses.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/1/2005 19:32'!
selectNoClasses
	classesSelected := Set new.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 11/1/2005 19:36'!
selectSubclasses
	| classesForPackages |
	classesForPackages := self findClassesForCategories: categoriesSelected.	
	classesSelected := (classesSelected gather: [ :class |
		class withAllSubclasses select: [ :each |
			classesForPackages includes: each ] ])
		asSet.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'utilities' stamp: 'lr 10/10/2005 08:43'!
sortClass: aFirstClass before: aSecondClass
	| first second |
	first := aFirstClass withAllSuperclasses reversed.
	second := aSecondClass withAllSuperclasses reversed.
	1 to: (first size min: second size) do: [ :index | 
		(first at: index) == (second at: index)
			ifFalse: [ ^ (first at: index) name <= (second at: index) name ] ].
	^ second includes: aFirstClass.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 11/1/2005 19:37'!
statusColor
	result hasPassed 
		ifTrue:[ ^ Color green ].
	result hasErrors 
		ifTrue: [ ^ Color red ].
	^ Color yellow.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:45'!
statusText
	^ result printString.! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 11/3/2005 09:37'!
suiteAll
	^ TestSuite new in: [ :suite |
		classesSelected do: [ :each | 
			each isAbstract 
				ifFalse: [ each addToSuiteFromSelectors: suite ] ].
		suite name: (self label: 'Test' forSuite: suite) ].! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/27/2005 10:29'!
suiteErrors
	^ TestSuite new in: [ :suite |
		suite 
			addTests: errorList; 
			name: (self label: 'Error' forSuite: suite) ].! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/27/2005 10:42'!
suiteFailures
	^ TestSuite new in: [ :suite |
		suite 
			addTests: failedList; 
			name: (self label: 'Failure' forSuite: suite) ].! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 10/31/2005 15:45'!
updateCategories
	categories := self findCategories.
	categoriesSelected := categoriesSelected isNil
		ifTrue: [ Set new ]
		ifFalse: [
			categoriesSelected
				select: [ :each | categories includes: each ] ].
	self changed: #categoryList; changed: #categorySelected.! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 10/31/2005 15:45'!
updateClasses
	| classesForCategories |
	classesForCategories := self findClassesForCategories: categoriesSelected.
	classes := classesForCategories asArray
		sort: [ :a :b | self sortClass: a before: b ].
	classesSelected := classesSelected isNil
		ifTrue: [ classesForCategories ]
		ifFalse: [ 
			classesSelected
				select: [ :each | classesForCategories includes: each ] ].
	self changed: #classList; changed: #classSelected.! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 11/3/2005 09:15'!
updateResults
	"<lint: #ignore rule: #guardingClause>"
	"<lint: #ignore rule: #longMethods>"

	self updateStatus: false.
	failedList size = result failures size ifFalse: [
		failedList := result failures asArray
			sort: [ :a :b | a printString <= b printString ].
		failedSelected := nil.
		self changed: #failedList; changed: #failedSelected ].
	errorList size = result errors size ifFalse: [
		errorList := result errors asArray
			sort: [ :a :b | a printString <= b printString ].
		errorSelected := nil.
		self changed: #errorList; changed: #errorSelected ].! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 11/3/2005 09:28'!
updateStatus: aBoolean
	"Update the status display, at most once a second if aBoolean is true."

	(aBoolean and: [ lastUpdate = Time totalSeconds ])
		ifTrue: [ ^ self ].
	self changed: #statusText; changed: #statusColor.
	lastUpdate := Time totalSeconds.! !

TestCase subclass: #ESLintTestCase
	instanceVariableNames: 'environment context debug'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESLintTestCase commentStamp: 'lr 10/28/2005 14:32' prior: 0!
<lint: #expect rule: #implementedNotSent rational: 'all the test methods are sent from sunit'>!

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/26/2005 21:15'!
buildAll
	BasicLintRule withAllSubclassesDo: [ :each | self buildForClass: each ].! !

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/11/2005 22:18'!
buildForClass: aClass
	aClass protocols do: [ :each | self buildForClass: aClass protocol: each ].! !

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/11/2005 22:20'!
buildForClass: aClass protocol: aProtocol 
	(aClass class organization listAtCategoryNamed: aProtocol)
		do: [ :each | self buildForClass: aClass protocol: aProtocol method: each ].! !

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/28/2005 01:36'!
buildForClass: aClass protocol: aProtocol method: aSelector
	"<lint: #ignore rule: #longMethods>"
	| selector |
	selector := String streamContents: [ :stream |
		stream nextPut: aSelector first asUppercase.
		stream nextPutAll: aSelector allButFirst ].
	self
		compile: (String streamContents: [ :stream |
			stream nextPutAll: 'test'; nextPutAll: selector; cr.
			stream tab; nextPutAll: 'self'; cr.
			stream tab; tab; nextPutAll: 'run: #'; nextPutAll: aSelector; cr.
			stream tab; tab; nextPutAll: 'rule: '; print: aClass; space; nextPutAll: aSelector; nextPut: $. ])
		classified: (String streamContents: [ :stream |
			stream nextPutAll: 'testing-'.
			aProtocol readStream in: [ :input |
				[ input atEnd ] whileFalse: [
					stream nextPutAll: (input upTo: Character space).
					input atEnd ifFalse: [ stream nextPut: $- ] ] ] ]).! !

!ESLintTestCase class methodsFor: 'testing' stamp: 'lr 10/26/2005 17:27'!
isAbstract
	^ super isAbstract or: [ self sunitName = #ESLintTestCase ].! !

!ESLintTestCase class methodsFor: 'accessing' stamp: 'lr 10/26/2005 17:25'!
resources
	^ Array with: ESLintTestResource.! !

!ESLintTestCase methodsFor: 'processing' stamp: 'lr 10/28/2005 12:59'!
check: aLintSelector rule: aLintRule
	debug ifTrue: [ ^ self ].
	self assert: aLintRule isEmpty.
	aLintRule resetResult.! !

!ESLintTestCase methodsFor: 'processing' stamp: 'lr 10/28/2005 14:34'!
debug
	"<lint: #expect rule: #overridesSuper rational: 'our debugging strategy is completly different to the one of the super-class'>"

	debug := true.
	self run.! !

!ESLintTestCase methodsFor: 'accessing' stamp: 'lr 10/28/2005 00:17'!
environment
	"Answer the environment to be used with this test-case, defaults to the whole image."
	
	^ BrowserEnvironment new.! !

!ESLintTestCase methodsFor: 'initialization' stamp: 'lr 10/28/2005 00:00'!
initialize
	super initialize.
	debug := false.! !

!ESLintTestCase methodsFor: 'processing' stamp: 'lr 10/28/2005 11:13'!
run: aLintSelector rule: aLintRule
	environment classes asArray
		do: [ :each | self run: aLintSelector rule: aLintRule class: each ]
		displayingProgress: (aLintRule name truncateWithElipsisTo: 25).
	(debug and: [ aLintRule isEmpty not ])
		ifTrue: [ aLintRule result label: aLintRule name; openEditor ].! !

!ESLintTestCase methodsFor: 'processing' stamp: 'lr 10/28/2005 13:44'!
run: aLintSelector rule: aLintRule class: aClass
	context selectedClass: aClass.
	(context isIgnored: aLintSelector)
		ifTrue: [ ^ self ].
	aLintRule checkClass: context.
	self check: aLintSelector rule: aLintRule.
	environment
		selectorsForClass: aClass
		do: [ :each | self run: aLintSelector rule: aLintRule class: aClass selector: each ].! !

!ESLintTestCase methodsFor: 'processing' stamp: 'lr 10/28/2005 13:44'!
run: aLintSelector rule: aLintRule class: aClass selector: aSelector
	context selector: aSelector.
	(context isIgnored: aLintSelector)
		ifTrue: [ ^ self ].
	aLintRule checkMethod: context.
	self check: aLintSelector rule: aLintRule.! !

!ESLintTestCase methodsFor: 'running' stamp: 'lr 10/28/2005 00:16'!
setUp
	| resource |
	super setUp.
	resource := self class resources first current.
	environment := resource environmentFor: self.
	context := resource context.! !

!ESLintTestCase methodsFor: 'running' stamp: 'lr 10/28/2005 00:16'!
tearDown
	super tearDown.
	environment := context := nil.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testAbstractClass
	self
		run: #abstractClass
		rule: BlockLintRule abstractClass.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testAddRemoveDependents
	self
		run: #addRemoveDependents
		rule: BlockLintRule addRemoveDependents.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testAsOrderedCollectionNotNeeded
	self
		run: #asOrderedCollectionNotNeeded
		rule: ParseTreeLintRule asOrderedCollectionNotNeeded.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testAssignmentInBlock
	self
		run: #assignmentInBlock
		rule: ParseTreeLintRule assignmentInBlock.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testAssignmentInIfTrue
	self
		run: #assignmentInIfTrue
		rule: ParseTreeLintRule assignmentInIfTrue.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testAtIfAbsent
	self
		run: #atIfAbsent
		rule: ParseTreeLintRule atIfAbsent.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testBadMessage
	self
		run: #badMessage
		rule: BlockLintRule badMessage.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/28/2005 14:02'!
testBooleanPrecedence
	self
		run: #booleanPrecedence
		rule: ParseTreeLintRule booleanPrecedence.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testClassInstVarNotInitialized
	self
		run: #classInstVarNotInitialized
		rule: BlockLintRule classInstVarNotInitialized.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testClassNameInSelector
	self
		run: #classNameInSelector
		rule: BlockLintRule classNameInSelector.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testClassNotReferenced
	self
		run: #classNotReferenced
		rule: BlockLintRule classNotReferenced.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testCollectionCopyEmpty
	self
		run: #collectionCopyEmpty
		rule: BlockLintRule collectionCopyEmpty.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testCollectionMessagesToExternalObject
	self
		run: #collectionMessagesToExternalObject
		rule: ParseTreeLintRule collectionMessagesToExternalObject.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testCollectionProtocol
	self
		run: #collectionProtocol
		rule: ParseTreeLintRule collectionProtocol.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testCollectSelectNotUsed
	self
		run: #collectSelectNotUsed
		rule: ParseTreeLintRule collectSelectNotUsed.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testConsistencyCheck
	self
		run: #consistencyCheck
		rule: ParseTreeLintRule consistencyCheck.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testContains
	self
		run: #contains
		rule: ParseTreeLintRule contains.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testDefinesEqualNotHash
	self
		run: #definesEqualNotHash
		rule: BlockLintRule definesEqualNotHash.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testDetectContains
	self
		run: #detectContains
		rule: ParseTreeLintRule detectContains.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testEndTrueFalse
	self
		run: #endTrueFalse
		rule: ParseTreeLintRule endTrueFalse.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testEqualNotUsed
	self
		run: #equalNotUsed
		rule: ParseTreeLintRule equalNotUsed.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testEqualsTrue
	self
		run: #equalsTrue
		rule: ParseTreeLintRule equalsTrue.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testEquivalentSuperclassMethods
	self
		run: #equivalentSuperclassMethods
		rule: BlockLintRule equivalentSuperclassMethods.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testExtraBlock
	self
		run: #extraBlock
		rule: ParseTreeLintRule extraBlock.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testFileBlocks
	self
		run: #fileBlocks
		rule: ParseTreeLintRule fileBlocks.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testFullBlocks
	self
		run: #fullBlocks
		rule: BlockLintRule fullBlocks.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testGuardingClause
	self
		run: #guardingClause
		rule: ParseTreeLintRule guardingClause.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testIfTrueBlocks
	self
		run: #ifTrueBlocks
		rule: ParseTreeLintRule ifTrueBlocks.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testIfTrueReturns
	self
		run: #ifTrueReturns
		rule: ParseTreeLintRule ifTrueReturns.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testImplementedNotSent
	self
		run: #implementedNotSent
		rule: BlockLintRule implementedNotSent.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testInstVarInSubclasses
	self
		run: #instVarInSubclasses
		rule: BlockLintRule instVarInSubclasses.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testJustSendsSuper
	self
		run: #justSendsSuper
		rule: BlockLintRule justSendsSuper.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testLiteralArrayCharacters
	self
		run: #literalArrayCharacters
		rule: ParseTreeLintRule literalArrayCharacters.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testLiteralArrayContainsComma
	self
		run: #literalArrayContainsComma
		rule: BlockLintRule literalArrayContainsComma.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testLiteralArrayContainsSuspiciousTrueFalseOrNil
	self
		run: #literalArrayContainsSuspiciousTrueFalseOrNil
		rule: BlockLintRule literalArrayContainsSuspiciousTrueFalseOrNil.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testLongMethods
	self
		run: #longMethods
		rule: BlockLintRule longMethods.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testMinMax
	self
		run: #minMax
		rule: ParseTreeLintRule minMax.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testMissingSubclassResponsibility
	self
		run: #missingSubclassResponsibility
		rule: BlockLintRule missingSubclassResponsibility.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testMissingYourself
	self
		run: #missingYourself
		rule: ParseTreeLintRule missingYourself.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testModifiesCollection
	self
		run: #modifiesCollection
		rule: ParseTreeLintRule modifiesCollection.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testOnlyReadOrWritten
	self
		run: #onlyReadOrWritten
		rule: BlockLintRule onlyReadOrWritten.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/27/2005 23:59'!
testOverridesSpecialMessage
	self
		run: #overridesSpecialMessage
		rule: BlockLintRule overridesSpecialMessage.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testOverridesSuper
	self
		run: #overridesSuper
		rule: BlockLintRule overridesSuper.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testPrecedence
	self
		run: #precedence
		rule: ParseTreeLintRule precedence.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testRefersToClass
	self
		run: #refersToClass
		rule: BlockLintRule refersToClass.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testReturnInEnsure
	self
		run: #returnInEnsure
		rule: ParseTreeLintRule returnInEnsure.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testReturnsBooleanAndOther
	self
		run: #returnsBooleanAndOther
		rule: BlockLintRule returnsBooleanAndOther.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testReturnsIfTrue
	self
		run: #returnsIfTrue
		rule: ParseTreeLintRule returnsIfTrue.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testSearchingLiteral
	self
		run: #searchingLiteral
		rule: ParseTreeLintRule searchingLiteral.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testSendsDifferentSuper
	self
		run: #sendsDifferentSuper
		rule: BlockLintRule sendsDifferentSuper.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/27/2005 23:59'!
testSendsUnknownMessageToGlobal
	self
		run: #sendsUnknownMessageToGlobal
		rule: ParseTreeLintRule sendsUnknownMessageToGlobal.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/27/2005 23:59'!
testSentNotImplemented
	self
		run: #sentNotImplemented
		rule: BlockLintRule sentNotImplemented.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testSizeCheck
	self
		run: #sizeCheck
		rule: ParseTreeLintRule sizeCheck.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testStringConcatenation
	self
		run: #stringConcatenation
		rule: ParseTreeLintRule stringConcatenation.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/27/2005 23:59'!
testSubclassResponsibilityNotDefined
	self
		run: #subclassResponsibilityNotDefined
		rule: BlockLintRule subclassResponsibilityNotDefined.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testSuperSends
	self
		run: #superSends
		rule: BlockLintRule superSends.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testTempsReadBeforeWritten
	self
		run: #tempsReadBeforeWritten
		rule: BlockLintRule tempsReadBeforeWritten.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testTempVarOverridesInstVar
	self
		run: #tempVarOverridesInstVar
		rule: BlockLintRule tempVarOverridesInstVar.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testThreeElementPoint
	self
		run: #threeElementPoint
		rule: ParseTreeLintRule threeElementPoint.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testToDo
	self
		run: #toDo
		rule: ParseTreeLintRule toDo.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testToDoCollect
	self
		run: #toDoCollect
		rule: ParseTreeLintRule toDoCollect.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testToDoWithIncrement
	self
		run: #toDoWithIncrement
		rule: ParseTreeLintRule toDoWithIncrement.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/27/2005 23:59'!
testUndeclaredReference
	self
		run: #undeclaredReference
		rule: BlockLintRule undeclaredReference.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testUnnecessaryAssignment
	self
		run: #unnecessaryAssignment
		rule: ParseTreeLintRule unnecessaryAssignment.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testUnoptimizedAndOr
	self
		run: #unoptimizedAndOr
		rule: ParseTreeLintRule unoptimizedAndOr.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testUnoptimizedToDo
	self
		run: #unoptimizedToDo
		rule: ParseTreeLintRule unoptimizedToDo.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testUnreferencedVariables
	self
		run: #unreferencedVariables
		rule: BlockLintRule unreferencedVariables.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/27/2005 23:59'!
testUsesAdd
	self
		run: #usesAdd
		rule: ParseTreeLintRule usesAdd.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/27/2005 23:59'!
testUsesTrue
	self
		run: #usesTrue
		rule: BlockLintRule usesTrue.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testUtilityMethods
	self
		run: #utilityMethods
		rule: BlockLintRule utilityMethods.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testVariableAssignedLiteral
	self
		run: #variableAssignedLiteral
		rule: BlockLintRule variableAssignedLiteral.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/27/2005 23:59'!
testVariableNotDefined
	self
		run: #variableNotDefined
		rule: BlockLintRule variableNotDefined.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/27/2005 23:59'!
testVariableReferencedOnce
	self
		run: #variableReferencedOnce
		rule: BlockLintRule variableReferencedOnce.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/27/2005 23:59'!
testWhileTrue
	self
		run: #whileTrue
		rule: ParseTreeLintRule whileTrue.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/27/2005 23:59'!
testYourselfNotUsed
	self
		run: #yourselfNotUsed
		rule: ParseTreeLintRule yourselfNotUsed.! !

ESLintTestCase subclass: #ESSelfTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESSelfTest methodsFor: 'accessing' stamp: 'lr 10/28/2005 00:18'!
environment
	^ super environment forPackage: (PackageInfo named: 'Essential').! !
ESTestRunner initialize!
